@@ -14,13 +14,16 @@ config: nonebot.config.Config = driver.config
 
 mongodb_opened: bool = False
 
+if config.mongodb_host:
+    mongodb_client = motor_asyncio.AsyncIOMotorClient(
+        f"mongodb://{config.mongodb_user}:{config.mongodb_password}@{config.mongodb_host}:{config.mongodb_port}")
+    nonebot.export().mongodb_client = mongodb_client
+
 
 @driver.on_startup
 async def connect_to_mongodb():
     global mongodb_opened
-    if config.mongodb_host is not None:
-        nonebot.require("nonebot_plugin_navicat").mongodb_client = motor_asyncio.AsyncIOMotorClient(
-            f"mongodb://{config.mongodb_user}:{config.mongodb_password}@{config.mongodb_host}:{config.mongodb_port}")
+    if config.mongodb_host:
         mongodb_opened = True
         nonebot.logger.info("connect to mongodb")
 
@@ -29,7 +32,6 @@ async def connect_to_mongodb():
 async def free_db():
     global mongodb_opened
     if mongodb_opened:
-        mongodb_client: motor_asyncio.AsyncIOMotorClient = nonebot.require("nonebot_plugin_navicat").mongodb_client
         mongodb_client.close()
         mongodb_opened = False
         nonebot.logger.info("disconnect to mongodb")
